@@ -59,7 +59,7 @@ move_to_fixedlist(node *stn, int ignore_dirn)
     }
 }
 
-int fix_station(prefix *fix_name, const double* coords) {
+int fix_station(prefix *fix_name, const double* coords, long offset) {
     bool new_stn = (fix_name->stn == NULL &&
 		    !TSTBIT(fix_name->sflags, SFLAGS_SOLVED));
     fix_name->sflags |= BIT(SFLAGS_FIXED);
@@ -88,6 +88,7 @@ int fix_station(prefix *fix_name, const double* coords) {
     // Make the station's file:line location reflect where it was fixed.
     fix_name->filename = file.filename;
     fix_name->line = file.line;
+    fix_name->column = offset >= 0 ? offset - file.lpos : 0;
     return 0;
 }
 
@@ -656,7 +657,7 @@ cmd_set(void)
 /*FIXME	{"CLOSE",     SPECIAL_CLOSE }, */
 	{"COMMENT",   SPECIAL_COMMENT },
 	{"DECIMAL",   SPECIAL_DECIMAL },
-	{"EOL",       SPECIAL_EOL }, /* EOL won't work well */
+	{"EOL",       SPECIAL_EOL },
 	{"KEYWORD",   SPECIAL_KEYWORD },
 	{"MINUS",     SPECIAL_MINUS },
 	{"NAMES",     SPECIAL_NAMES },
@@ -728,13 +729,13 @@ cmd_set(void)
 	    set_pos(&fp);
 	    break;
 	 }
-	 hex = isdigit(ch) ? ch - '0' : tolower(ch) - 'a';
+	 hex = isdigit(ch) ? ch - '0' : tolower(ch) - 'a' + 10;
 	 nextch();
 	 if (!isxdigit(ch)) {
 	    set_pos(&fp);
 	    break;
 	 }
-	 hex = hex << 4 | (isdigit(ch) ? ch - '0' : tolower(ch) - 'a');
+	 hex = hex << 4 | (isdigit(ch) ? ch - '0' : tolower(ch) - 'a' + 10);
 	 char_to_set = hex;
       } else {
 	 break;
@@ -816,6 +817,7 @@ check_reentry(prefix *survey, const filepos* fpos_ptr)
       survey->sflags |= BIT(SFLAGS_PREFIX_ENTERED);
       survey->filename = file.filename;
       survey->line = file.line;
+      survey->column = fpos_ptr->offset - file.lpos;
    }
 }
 
@@ -823,21 +825,9 @@ check_reentry(prefix *survey, const filepos* fpos_ptr)
 static void
 cmd_prefix(void)
 {
-   static int prefix_depr_count = 0;
-   prefix *survey;
    filepos fp;
-   /* Issue warning first, so "*prefix \" warns first that *prefix is
-    * deprecated and then that ROOT is...
-    */
-   if (prefix_depr_count < 5) {
-      /* TRANSLATORS: If you're unsure what "deprecated" means, see:
-       * https://en.wikipedia.org/wiki/Deprecation */
-      compile_diagnostic(DIAG_WARN|DIAG_TOKEN, /**prefix is deprecated - use *begin and *end instead*/109);
-      if (++prefix_depr_count == 5)
-	 compile_diagnostic(DIAG_INFO, /*Further uses of this deprecated feature will not be reported*/95);
-   }
    get_pos(&fp);
-   survey = read_prefix(PFX_SURVEY|PFX_ALLOW_ROOT);
+   prefix *survey = read_prefix(PFX_SURVEY|PFX_ALLOW_ROOT);
    pcs->Prefix = survey;
    check_reentry(survey, &fp);
 }
@@ -879,7 +869,6 @@ cmd_begin(void)
    pcsNew->next = pcs;
    pcs = pcsNew;
 
-   skipblanks();
    pcs->begin_survey = NULL;
    pcs->begin_col = 0;
    if (!isEol(ch) && !isComm(ch)) {
@@ -948,64 +937,6 @@ report_declination(settings *p)
     }
 }
 
-void
-set_declination_location(real x, real y, real z, const char *proj_str)
-{
-    /* Convert to WGS84 lat long. */
-    PJ *transform = proj_create_crs_to_crs(PJ_DEFAULT_CTX,
-					   proj_str,
-					   WGS84_DATUM_STRING,
-					   NULL);
-    if (transform) {
-	/* Normalise the output order so x is longitude and y latitude - by
-	 * default new PROJ has them switched for EPSG:4326 which just seems
-	 * confusing.
-	 */
-	PJ* pj_norm = proj_normalize_for_visualization(PJ_DEFAULT_CTX,
-						       transform);
-	proj_destroy(transform);
-	transform = pj_norm;
-    }
-
-    if (proj_angular_input(transform, PJ_FWD)) {
-	/* Input coordinate system expects radians. */
-	x = rad(x);
-	y = rad(y);
-    }
-
-    PJ_COORD coord = {{x, y, z, HUGE_VAL}};
-    coord = proj_trans(transform, PJ_FWD, coord);
-    x = coord.xyzt.x;
-    y = coord.xyzt.y;
-    z = coord.xyzt.z;
-
-    if (x == HUGE_VAL || y == HUGE_VAL || z == HUGE_VAL) {
-       compile_diagnostic(DIAG_ERR, /*Failed to convert coordinates: %s*/436,
-			  proj_context_errno_string(PJ_DEFAULT_CTX,
-						    proj_errno(transform)));
-       /* Set dummy values which are finite. */
-       x = y = z = 0;
-    }
-    proj_destroy(transform);
-
-    report_declination(pcs);
-
-    double lon = rad(x);
-    double lat = rad(y);
-    pcs->z[Q_DECLINATION] = HUGE_REAL;
-    pcs->dec_lat = lat;
-    pcs->dec_lon = lon;
-    pcs->dec_alt = z;
-    pcs->dec_filename = file.filename;
-    pcs->dec_line = file.line;
-    pcs->dec_context = grab_line();
-    /* Invalidate cached declination. */
-    pcs->declination = HUGE_REAL;
-    /* Invalidate cached grid convergence values. */
-    pcs->convergence = HUGE_REAL;
-    pcs->input_convergence = HUGE_REAL;
-}
-
 void
 pop_settings(void)
 {
@@ -1078,7 +1009,6 @@ cmd_end(void)
 
    /* note need to read using root *before* BEGIN */
    prefix *survey = NULL;
-   skipblanks();
    if (!isEol(ch) && !isComm(ch)) {
       get_pos(&fp);
       survey = read_prefix(PFX_SURVEY|PFX_ALLOW_ROOT);
@@ -1159,6 +1089,9 @@ cmd_fix(void)
       if (!s_empty(&uctoken)) set_pos(&fp);
    }
 
+   skipblanks();
+   get_pos(&fp);
+
    // If `REFERENCE` is specified the coordinates can't be omitted.
    coord.v[0] = read_numeric(!reference);
    if (coord.v[0] == HUGE_REAL) {
@@ -1233,7 +1166,8 @@ cmd_fix(void)
 	 if (coord.v[0] == HUGE_VAL ||
 	     coord.v[1] == HUGE_VAL ||
 	     coord.v[2] == HUGE_VAL) {
-	    compile_diagnostic(DIAG_ERR, /*Failed to convert coordinates: %s*/436,
+	    compile_diagnostic(DIAG_ERR|DIAG_FROM(fp),
+			       /*Failed to convert coordinates: %s*/436,
 			       proj_context_errno_string(PJ_DEFAULT_CTX,
 							 proj_errno(transform)));
 	    /* Set dummy values which are finite. */
@@ -1321,7 +1255,7 @@ cmd_fix(void)
       first_fix_line = file.line;
    }
 
-   int fix_result = fix_station(fix_name, coord.v);
+   int fix_result = fix_station(fix_name, coord.v, fp_stn.offset);
    if (reference) {
        // `*fix reference` so suppress "unused fixed point" warning.
        fix_name->sflags &= ~BIT(SFLAGS_UNUSED_FIXED_POINT);
@@ -1403,6 +1337,7 @@ cmd_equate(void)
 	  // reflect this *equate.
 	  name->filename = file.filename;
 	  name->line = file.line;
+	  name->column = fp.offset - file.lpos;
       }
       skipblanks();
       if (isEol(ch) || isComm(ch)) {
@@ -2093,10 +2028,12 @@ cmd_declination(void)
 	}
 
 	/* *declination auto X Y Z */
+	filepos fp;
+	get_pos(&fp);
 	real x = read_numeric(false);
 	real y = read_numeric(false);
 	real z = read_numeric(false);
-	set_declination_location(x, y, z, pcs->proj_str);
+	set_declination_location(x, y, z, pcs->proj_str, &fp);
     } else {
 	/* *declination D UNITS */
 	int units = get_units(BIT(Q_DECLINATION), false);
@@ -2118,15 +2055,6 @@ cmd_default(void)
       { "UNITS",     CMD_UNITS },
       { NULL,	     CMD_NULL }
    };
-   static int default_depr_count = 0;
-
-   if (default_depr_count < 5) {
-      /* TRANSLATORS: If you're unsure what "deprecated" means, see:
-       * https://en.wikipedia.org/wiki/Deprecation */
-      compile_diagnostic(DIAG_WARN|DIAG_TOKEN, /**DEFAULT is deprecated - use *CALIBRATE/DATA/SD/UNITS with argument DEFAULT instead*/20);
-      if (++default_depr_count == 5)
-	 compile_diagnostic(DIAG_INFO, /*Further uses of this deprecated feature will not be reported*/95);
-   }
 
    get_token();
    switch (match_tok(defaulttab, TABSIZE(defaulttab))) {
@@ -2340,7 +2268,6 @@ cmd_case(void)
 static void
 cmd_copyright(void)
 {
-    skipblanks();
     filepos fp;
     get_pos(&fp);
     unsigned y1 = read_uint_raw(DIAG_WARN|DIAG_UINT, /*Invalid year*/534, NULL);
@@ -2798,7 +2725,6 @@ cmd_require(void)
     // Add extra 0 so `*require 1.4.10.1` fails with cavern version 1.4.10.
     const unsigned version[] = {COMMAVERSION, 0};
 
-    skipblanks();
     filepos fp;
     get_pos(&fp);
 
@@ -3174,7 +3100,6 @@ handle_command(void)
     case CMD_DATA:
     case CMD_DATE:
     case CMD_DECLINATION:
-    case CMD_DEFAULT:
     case CMD_FLAGS:
     case CMD_INFER:
     case CMD_INSTRUMENT:
@@ -3186,13 +3111,41 @@ handle_command(void)
     case CMD_TITLE:
     case CMD_TRUNCATE:
     case CMD_UNITS:
-      /* These can occur between *begin and *export */
+      /* These can all occur between *begin and *export */
       break;
+    case CMD_DEFAULT: {
+      // Issue warning here before we skipblanks().
+      static int default_depr_count = 0;
+      if (default_depr_count < 5) {
+	  /* TRANSLATORS: If you're unsure what "deprecated" means, see:
+	   * https://en.wikipedia.org/wiki/Deprecation */
+	  compile_diagnostic(DIAG_WARN|DIAG_TOKEN, /**DEFAULT is deprecated - use *CALIBRATE/DATA/SD/UNITS with argument DEFAULT instead*/20);
+	  if (++default_depr_count == 5)
+	      compile_diagnostic(DIAG_INFO, /*Further uses of this deprecated feature will not be reported*/95);
+      }
+      /* Can occur between *begin and *export */
+      break;
+    }
+    case CMD_PREFIX: {
+      // Issue warning here before we skipblanks().
+      static int prefix_depr_count = 0;
+      if (prefix_depr_count < 5) {
+	  /* TRANSLATORS: If you're unsure what "deprecated" means, see:
+	   * https://en.wikipedia.org/wiki/Deprecation */
+	  compile_diagnostic(DIAG_WARN|DIAG_TOKEN, /**prefix is deprecated - use *begin and *end instead*/109);
+	  if (++prefix_depr_count == 5)
+	      compile_diagnostic(DIAG_INFO, /*Further uses of this deprecated feature will not be reported*/95);
+      }
+      f_export_ok = false;
+      break;
+    }
     default:
       /* NB: additional handling for "*begin <survey>" in cmd_begin */
       f_export_ok = false;
       break;
    }
 
+   skipblanks();
+
    cmd_funcs[cmdtok]();
 }
