@@ -25,7 +25,7 @@
 #include <stdio.h>
 #include "wx.h"
 
-#include "img_hosted.h"
+#include "img_for_survex.h"
 
 class ExportFilter {
   protected:
@@ -41,7 +41,6 @@ class ExportFilter {
 	return (fh != NULL);
     }
     virtual void header(const char* title,
-			const char* datestamp_string,
 			time_t datestamp,
 			double min_x, double min_y, double min_z,
 			double max_x, double max_y, double max_z);
@@ -59,7 +58,6 @@ class ExportFilter {
 
 inline void
 ExportFilter::header(const char*,
-		     const char*,
 		     time_t,
 		     double, double, double,
 		     double, double, double) { }
