@@ -156,19 +156,7 @@ class GLACanvas : public wxGLCanvas {
     int x_size = 0;
     int y_size = 0;
 
-    // wxHAS_DPI_INDEPENDENT_PIXELS is new in 3.1.6.  In older versions we just
-    // always do the scaling which is slightly less efficient for platforms
-    // where pixel coordinates don't scale with DPI.
-#if defined wxHAS_DPI_INDEPENDENT_PIXELS || \
-    !wxCHECK_VERSION(3,1,6)
-# define HAS_DPI_INDEPENDENT_PIXELS
-#endif
-
-#ifdef HAS_DPI_INDEPENDENT_PIXELS
-    double content_scale_factor = 1.0;
-#else
-    static constexpr unsigned content_scale_factor = 1;
-#endif
+    double dpi_scale_factor = 1.0;
 
     vector<GLAList> drawing_lists;
 
@@ -186,6 +174,8 @@ class GLACanvas : public wxGLCanvas {
 
     bool CheckVisualFidelity(const unsigned char * target) const;
 
+    void UpdateSize();
+
 public:
     GLACanvas(wxWindow* parent, int id);
     ~GLACanvas();
@@ -333,31 +323,26 @@ public:
 	return y_size;
     }
 
-#ifdef HAS_DPI_INDEPENDENT_PIXELS
-    double GetContentScaleFactor() const {
+    double GetDPIScaleFactor() const {
 	list_flags |= INVALIDATE_ON_HIDPI;
-	return content_scale_factor;
+	return dpi_scale_factor;
     }
 
-    void UpdateContentScaleFactor();
     void OnMove(wxMoveEvent & event);
-#else
-    // wxWindow::GetContentScaleFactor() will always return 1.0, so arrange
-    // things so it's a compile-time constant the compiler can optimise away.
-    // Use a macro so we can return unsigned instead of double without a lot
-    // of pain from trying to override a virtual method while changing the
-    // return type.
-# define GetContentScaleFactor() 1u
-    void UpdateContentScaleFactor() { }
-#endif
 
     void OnSize(wxSizeEvent & event);
 
     glaCoord GetVolumeDiameter() const { return m_VolumeDiameter; }
 
     void ScaleMouseEvent(wxMouseEvent& e) const {
+#ifdef wxHAS_DPI_INDEPENDENT_PIXELS
+	auto content_scale_factor = GetContentScaleFactor();
+
 	e.SetX(e.GetX() * content_scale_factor);
 	e.SetY(e.GetY() * content_scale_factor);
+#else
+	(void)e;
+#endif
     }
 
 private:
