@@ -28,8 +28,7 @@ MyLogWindow::MyLogWindow()
      * currently) */
     : wxLogWindow(NULL,
 		  wxString::Format(wmsg(/*%s Error Log*/228), APP_NAME).c_str(),
-		  false, false),
-      first(true)
+		  false, false)
 {
 }
 
