@@ -35,9 +35,8 @@
 
 #include "cmdline.h"
 #include "filename.h"
-#include "img_hosted.h"
+#include "img_for_survex.h"
 #include "message.h"
-#include "osalloc.h"
 #include "useful.h"
 
 #include <iostream>
@@ -68,7 +67,7 @@ main(int argc, char **argv)
        if (strcmp(progname, "3dtopos") == 0) {
 	   format = FMT_POS;
        }
-       osfree(progname);
+       free(progname);
    }
 
    const int OPT_FMT_BASE = 20000;
@@ -419,7 +418,7 @@ main(int argc, char **argv)
       char *baseleaf = baseleaf_from_fnm(fnm_in);
       /* note : memory allocated by fnm_out gets leaked in this case... */
       fnm_out = add_ext(baseleaf, export_format_info[format].extension);
-      osfree(baseleaf);
+      free(baseleaf);
    }
 
    const auto& format_info_mask = export_format_info[format].mask;
@@ -458,7 +457,6 @@ main(int argc, char **argv)
 
    try {
        if (!Export(fnm_out, model.GetSurveyTitle(),
-		   model.GetDateString(),
 		   model, filter,
 		   pan, tilt, show_mask, format,
 		   grid, text_height, marker_size,
